P4 to Git Change 1972922 by cpaquot@cpaquot-ocl-lc-lnx on 2019/07/24 11:59:16

SWDEV-196881 - [HIP] Fix hipStreamQuery implementation. Using isEmpty isn't correct.

Affected files ...

... //depot/stg/opencl/drivers/opencl/api/hip/hip_internal.hpp#32 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_stream.cpp#20 edit


[ROCm/clr commit: 47ac573d70]
Этот коммит содержится в:
foreman
2019-07-24 12:05:47 -04:00
родитель f1086b0b13
Коммит 38cfac4dcd
2 изменённых файлов: 13 добавлений и 1 удалений
+1
Просмотреть файл
@@ -159,6 +159,7 @@ extern amd::Memory* getMemoryObject(const void* ptr, size_t& offset);
#define HIP_RETURN(ret) \
hip::g_lastError = ret; \
LogPrintfInfo("[%zx] %s: Returned %s", std::this_thread::get_id(), __func__, hipGetErrorName(ret)); \
return hip::g_lastError; \
inline std::ostream& operator<<(std::ostream& os, const dim3& s) {
+12 -1
Просмотреть файл
@@ -210,7 +210,18 @@ hipError_t hipStreamQuery(hipStream_t stream) {
} else {
hostQueue = as_amd(reinterpret_cast<cl_command_queue>(stream))->asHostQueue();
}
HIP_RETURN(hostQueue->isEmpty() ? hipSuccess : hipErrorNotReady);
amd::Command* command = hostQueue->getLastQueuedCommand(false);
if (command == nullptr) {
HIP_RETURN(hipSuccess);
}
amd::Event& event = command->event();
if (command->type() != CL_COMMAND_MARKER) {
event.notifyCmdQueue();
}
HIP_RETURN((command->status() == CL_COMPLETE) ? hipSuccess : hipErrorNotReady);
}
hipError_t hipStreamAddCallback(hipStream_t stream, hipStreamCallback_t callback, void* userData,